@@ -22,7 +22,7 @@ Then open ``build/html/index.html`` in your web browser.  If that fails, you can
 
 """
 
-__version__ = "1.1.2"
+__version__ = "1.3"
 
 import logging
 import sys
@@ -36,4 +36,5 @@ from fixture.style import *
 def setup_test_not_supported():
     """hook for setup for the test command."""
     raise NotImplementedError("use: `python setup.py nosetests` instead")
+setup_test_not_supported.__test__ = False
     
\ No newline at end of file
