@@ -1,10 +1,12 @@
 
 """Loadable fixture components"""
 
-__all__ = ['SQLAlchemyFixture', 'SQLObjectFixture', 'GoogleDatastoreFixture']
+__all__ = ['SQLAlchemyFixture', 'SQLObjectFixture', 'GoogleDatastoreFixture',
+           'DjangoFixture']
 import loadable
 __doc__ = loadable.__doc__
 from loadable import *
 from sqlalchemy_loadable import SQLAlchemyFixture
 from sqlobject_loadable import SQLObjectFixture
-from google_datastore_loadable import GoogleDatastoreFixture
\ No newline at end of file
+from google_datastore_loadable import GoogleDatastoreFixture
+from django_loadable import DjangoFixture
\ No newline at end of file
